<?php

namespace Mihanwp\FastCheckout\App\Controller;

use Mihanwp\FastCheckout\App\Core\Config;
use Mihanwp\FastCheckout\App\Model\Gateway as ModelGateway;

class Products
{
    static function addShortcodeValueMetabox()
    {
        add_meta_box('mw_fastcheckout_shortcode', __('Fast checkout shortcode', 'aani_woocommerce'), [__CLASS__, 'metaboxShortcodeValue'], null, 'side', 'high');
    }
    static function enqueueEditProductViewAssets($hookSuffix)
    {
        $screen = get_current_screen();
        $screenID = $screen ? $screen->id : false;
        if ($screenID === 'product') {
            $version = Config::get_plugin_version();
            wp_enqueue_style(
                'admin-fast-checkout',
                MW_AANI_CHECKOUT_DIR_URL . 'assets/css/admin/metabox-product-fast-checkout.css',
                null,
                $version,
            );
            wp_enqueue_script(
                'admin-fast-checkout',
                MW_AANI_CHECKOUT_DIR_URL . 'assets/js/admin/metabox-product-fast-checkout.js',
                ['jquery'],
                $version,
                true
            );
            $data = [
                'messages' => [
                    'copy_done' => __("It's copy", 'aani_woocommerce')
                ]
            ];
            wp_localize_script(
                'admin-fast-checkout',
                'mwfc_data',
                $data
            );
        }
    }
    static function metaboxShortcodeValue($post)
    {
        $availablePaymentGateways = ModelGateway::getAvailableGateways();
?>
        <p class="mwfc-shortcode-wrapper" dir="ltr">
            <span class="button button-primary" id="mwfc-shortcode-btn"><?php esc_html_e('Get shortcode', 'aani_woocommerce') ?></span>
        </p>
        <div class="mwfc-shortcode-modal-wrapper" pid="<?php echo $post->ID?>">
            <div class="content-box">
                <span class="close-btn dashicons dashicons-no"></span>
                <div class="form-wrapper">
                    <div id="short-code-value-wrapper"></div>
                    <div id="mwfc-notice-box"></div>
                    <div class="section-wrapper gateways">
                        <span class="section-title"><?php esc_html_e('Gateway', 'aani_woocommerce') ?></span>
                        <div class="fields-section check-box-view">
                            <?php if ($availablePaymentGateways) : ?>
                                <?php $counter = 0; foreach ($availablePaymentGateways as $key => $item) : $counter++;?>
                                    <div class="input-item checkbox-item">
                                        <label for="<?php echo $key ?>">
                                            <input <?php checked($counter, 1)?> type="radio" name="mwfc_form_gateway" id="<?php echo $item->id ?>" value="<?php echo $item->id; ?>">
                                            <span class="input-value">
                                                <span class="icon"><?php echo $item->get_icon(); ?></span>
                                                <span class="title"><?php echo $item->get_title() ?></span>
                                            </span>
                                        </label>
                                    </div>
                                <?php endforeach; ?>
                            <?php else : ?>
                                <span><?php esc_html_e('No any available gateways found', 'aani_woocommerce') ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="checkout_btn_text"><?php esc_html_e('Checkout button text', 'aani_woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="text" value="<?php esc_html_e('Make payment', 'aani_woocommerce')?>" id="checkout_btn_text" name="checkout_btn_text">
                            </div>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="invoice_amount_text_field"><?php esc_html_e('Description of the form', 'aani_woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="text" value="<?php esc_html_e('Invoice payment amount', 'aani_woocommerce')?>" id="invoice_amount_text_field" name="invoice_amount_text_field">
                            </div>
                        </div>
                    </div>
                    <div class="section-wrapper">
                        <span class="section-title"><label for="order_qty_value"><?php esc_html_e('Quantity of product', 'aani_woocommerce')?></label></span>
                        <div class="fields-section">
                            <div class="input-item">
                                <input type="number" value="1" id="order_qty_value" name="order_qty_value">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-box"></div>
        </div>
<?php
    }
}
