<?php
namespace Mihanwp\FastCheckout\App\Core;

use Mihanwp\FastCheckout\App\Helpers\Phone;
use Mihanwp\FastCheckout\App\Model\Gateway;
use Mihanwp\FastCheckout\App\Model\Order as ModelOrder;
use Mihanwp\FastCheckout\App\Model\User as ModelUser;

class Ajax
{
    static function init()
    {
        add_action('wp_ajax_nopriv_mwfc_create_order_for_product', [__CLASS__, 'create_order_for_product']);
        add_action('wp_ajax_mwfc_create_order_for_product', [__CLASS__, 'create_order_for_product']);
    }
    private static function checkNonce($action, $query='nonce')
    {
        check_ajax_referer($action, $query);
    }
    private static function send($result)
    {
        die(json_encode($result));
    }
    static function create_order_for_product()
    {
        $result = [
            'status' => 'nok',
        ];
        $pid = isset($_POST['pid']) ? sanitize_text_field(intval($_POST['pid'])) : false;
        if(!$pid)
        {
            $result['msg'] = __('Missing product id', 'aani_woocommerce');
            self::send($result);
        }
        $gateway = isset($_POST['gateway']) ? sanitize_text_field($_POST['gateway']) : false;
        if(!$gateway)
        {
            $result['msg'] = __('Missing gateway id', 'aani_woocommerce');
            self::send($result);
        }
        if(!Gateway::validateGatewayId($gateway))
        {
            $result['msg'] = __('Invalid gateway id', 'aani_woocommerce');
            self::send($result);
        }
        $nonceAction = 'mwcfc_product_'.$pid.'_form_' . $gateway;
        self::checkNonce($nonceAction);
        $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : false;

        // check is valid phone number
        $phone = isset($_POST['phone']) ? Phone::validatePhone($_POST['phone']) : false;
        if(!$phone)
        {
            $result['msg'] = __('Missing valid phone number', 'aani_woocommerce');
            self::send($result);
        }

        $qty = isset($_POST['qty']) ? intval($_POST['qty']) : 1;

        // check is user logged-in
        if($userID = get_current_user_id())
        {
            // check has phone number
            $otherUser = ModelUser::getUserByPhone($phone);
            if($otherUser && $otherUser->ID !== $userID)
            {
                $result['msg'] = __('Phone number is not available', 'aani_woocommerce');
                self::send($result);
            }

            if(!ModelUser::getPhoneNumber($userID))
            {
                ModelUser::setPhoneNumber($userID, $phone);
                ModelUser::setHasValidPhoneNumber($userID);
            }
            // create order
            $newOrder = ModelOrder::createOrder($pid, $gateway, [
                'customer_id' => $userID,
                'phone' => $phone,
            ], $qty);

            if($newOrder && !is_wp_error($newOrder))
            {
                $result['status'] = 'ok';

                // check is free order
                if($newOrder->get_total() === "0")
                {
                    // complete the order
                    $newOrder->update_status('completed', __('Free product order', 'aani_woocommerce'));
                    $result['checkout_url'] = $newOrder->get_checkout_order_received_url();
                }else{
                    $result['checkout_url'] = $newOrder->get_checkout_payment_url(true);
                }
            }else{
                $result['status'] = 'nok';
                $result['msg'] = __('Has problem in creating your order', 'aani_woocommerce');
            }
            self::send($result);
        }
        
        // user not logged-in
        // check is user exists with this phone number
        // $userByPhone = ModelUser::getUserByPhone($phone);
        // create new user with this phone number if user not exists with that

        // create order for guest user
        $orderArgs = [
            'phone' => $phone,
        ];
        if($name)
        {
            $orderArgs['name'] = $name;
        }
        $newOrder = ModelOrder::createOrder($pid, $gateway, $orderArgs, $qty);
        if(!$newOrder || is_wp_error($newOrder))
        {
            $result['status'] = 'nok';
            $result['msg'] = __('Has problem in creating your order', 'aani_woocommerce');
            self::send($result);
        }
        
        $result['status'] = 'ok';
        // check is free order
        if($newOrder->get_total() === "0")
        {
            // complete the order
            $newOrder->update_status('completed', __('Free product order', 'aani_woocommerce'));
            $result['checkout_url'] = $newOrder->get_checkout_order_received_url();
        }else{
            $result['checkout_url'] = $newOrder->get_checkout_payment_url(true);
        }
        self::send($result);
    }
}