<?php
namespace Mihanwp\FastCheckout\App\Core;
class Assets
{
    static function init()
    {
        self::registerFastChecheckoutShortcodeAssets();
    }
    static function getAsset($fileName, $type, $extension)
    {
        $extension = $extension ? $extension : $type;
        $fileName = str_replace('.', '/', $fileName);
        $fileName = MW_AANI_CHECKOUT_DIR_URL . 'assets/' . $type . '/' . $fileName . '.' . $extension;
        return $fileName;
    }
    static function getJs($fileName, $isMinified=false)
    {
        $extension = $isMinified ? 'min.js' : 'js';
        return self::getAsset($fileName, 'js', $extension);
    }
    static function getCss($fileName, $isMinified=false)
    {
        $extension = $isMinified ? 'min.css' : 'css';
        return self::getAsset($fileName, 'css', $extension);
    }
    static function getImg($fileName, $extension='png')
    {
        return self::getAsset($fileName, 'img', $extension);
    }
    static function getHandleName($name)
    {
        return 'mw_quick_pay_' . $name;
    }
    static function enqueueScript($name, $src, $deps = ['jquery'], $version=null, $inFooter=true)
    {
        $name = self::getHandleName($name);
        $version = $version ? $version : Config::get_plugin_version();
        wp_enqueue_script($name, $src, $deps, $version, $inFooter);
    }
    static function enqueueStyle($name, $src, $version=null, $deps=[])
    {
        $name = self::getHandleName($name);
        $version = $version ? $version : Config::get_plugin_version();
        wp_enqueue_style($name, $src, $deps, $version);
    }
    static function localizeScript($name, $object_name, $data)
    {
        $name = self::getHandleName($name);
        wp_localize_script($name, $object_name, $data);
    }
    static function registerFastChecheckoutShortcodeAssets()
    {
        $fastCheckoutCss = MW_AANI_CHECKOUT_DIR_URL . 'assets/css/fast-checkout.css';
        $fastCheckoutJs = MW_AANI_CHECKOUT_DIR_URL . 'assets/js/fast-checkout.js';

        $version = Config::get_plugin_version();
        wp_register_style('mw_aani_checkout_shortcode', $fastCheckoutCss, [], $version);
        wp_register_script('mw_aani_checkout_shortcode', $fastCheckoutJs, ['jquery'], $version, true);
        $data = [
            'au' => admin_url('admin-ajax.php'),
            'messages' => [
                'has_error_in_request' => __('Has error in request', 'aani_woocommerce'),
                'missing_field_value' => esc_html__('Missing some fields data', 'aani_woocommerce'),
                'redirecting_to_payment_gateway' => __('Redirecting to payment gateway', 'aani_woocommerce'),
            ],
        ];
        wp_localize_script('mw_aani_checkout_shortcode', 'mwfc', $data);
    }
    static function loadFastCheckoutShortcodeAssets()
    {
        wp_enqueue_style('mw_aani_checkout_shortcode');
        wp_enqueue_script('mw_aani_checkout_shortcode');
    }
}