<?php

namespace Mihanwp\FastCheckout\App\Model;

use Mihanwp\FastCheckout\App\Helpers\Phone;
use Mihanwp\FastCheckout\App\Helpers\Tools;

class Order
{
    private const IS_FAST_CHECKOUT_OPTION_NAME = 'mwfc_is_fast_checkout';
    static function createOrder($productID, $gateway, $args = [], $qty = 1)
    {
        if(!$productID || !$gateway || !Gateway::validateGatewayId($gateway))
        {
            return false;
        }
        $order = wc_create_order();
        if ($order) {
            if (isset($args['customer_id'])) {
                $order->set_customer_id($args['customer_id']);
            }
            $product = wc_get_product($productID);
            if (!$product) {
                return false;
            }
            $order->add_product($product, $qty);
            if (isset($args['phone'])) {
                $phone = Phone::validatePhone($args['phone']);
                if ($phone) {
                    $order->set_billing_phone($phone);
                }
            }
            if(isset($args['name']))
            {
                $order->set_billing_first_name($args['name']);
            }
            $order->add_meta_data(self::IS_FAST_CHECKOUT_OPTION_NAME, 1);
            $order->calculate_totals();
            $order->set_payment_method($gateway);
            $order->save();
        }
        return $order;
    }
    static function isFastCheckoutOrder($orderID)
    {
        if(version_compare(Tools::getWoocommerceVersion(), '9', '>=')){
            $order = wc_get_order($orderID);

            $value = is_object($order) && method_exists($order, 'get_meta') ? $order->get_meta(self::IS_FAST_CHECKOUT_OPTION_NAME) : false;
            if ($value)
                return $value;
        }

        return get_post_meta($orderID, self::IS_FAST_CHECKOUT_OPTION_NAME, true);
    }
}
