<?php

namespace Mihanwp\FastCheckout\App\Model;

use Mihanwp\FastCheckout\App\Helpers\Phone;
use Mihanwp\FastCheckout\App\Helpers\Tools;

class User
{
    private const PHONE_OPTION_NAME = 'mw_user_phone';
    private const HAS_VALID_PHONE_NUMBER_OPTION_NAME = 'mw_user_has_valid_phone';

    static function hasValidPhoneNumber($uid)
    {
        return get_user_meta($uid, self::HAS_VALID_PHONE_NUMBER_OPTION_NAME, true);
    }
    static function setHasValidPhoneNumber($uid)
    {
        return update_user_meta($uid, self::HAS_VALID_PHONE_NUMBER_OPTION_NAME, 1);
    }
    static function unsetHasValidPhoneNumber($uid)
    {
        return delete_user_meta($uid, self::HAS_VALID_PHONE_NUMBER_OPTION_NAME);
    }

    static function getPhoneNumber($userID)
    {
        return get_user_meta($userID, self::PHONE_OPTION_NAME, true);
    }
    static function setPhoneNumber($userID, $phoneNumber)
    {
        if (!$userID) {
            return false;
        }
        $phoneNumber = Phone::validatePhone($phoneNumber);
        if (!$phoneNumber) {
            return false;
        }
        return update_user_meta($userID, self::PHONE_OPTION_NAME, $phoneNumber);
    }
    static function getUserByPhone($phone)
    {
        $phone = Phone::validatePhone($phone);
        if (!$phone) {
            return false;
        }
        // check username
        $userData = get_user_by('login', 'user_' . $phone);
        if (!$userData) {
            // get user by phone meta
            $userData = get_users([
                'meta_key' => self::PHONE_OPTION_NAME,
                'meta_value' => $phone,
                'number' => 1,
            ]);
            $userData = $userData && is_array($userData) ? array_shift($userData) : $userData;
        }
        return $userData instanceof \WP_User ? $userData : false;
    }
    static function createUserWithPhone($phone, $args = [])
    {
        $phone = Phone::validatePhone($phone);
        if (!$phone) {
            return false;
        }
        $username = 'user_' . $phone;
        $display_name = isset($args['display_name']) ? sanitize_text_field($args['display_name']) : false;
        $args = [
            'user_login' => $username,
            'display_name' => $display_name,
            'user_email' => Tools::generateFakeMail($username)
        ];
        $newUserID = wp_insert_user($args);
        if($newUserID)
        {
            update_user_meta($newUserID, self::PHONE_OPTION_NAME, $phone);
            self::setHasValidPhoneNumber($newUserID);
        }
        return $newUserID;
    }
}
