jQuery(document).ready(function ($) {
    let checkoutForm = $('form.fast-checkout-wrapper'),
        redirecting = false
    function notice(formWrapper, msg, type='error') {
        let noticeBox = formWrapper.find('.notice-box'),
            notice = $('<span>')
        notice.addClass(type)
        notice.text(msg)
        noticeBox.html(notice)
        setTimeout(() => {
            notice.remove()
        }, 2000);
    }
    checkoutForm.each((index, value) => {
        let form = $(value),
            btn = form.find('.mw_fast_checkout_pay_btn'),
            phoneNumber = form.find('input[name=phone-number]'),
            name = form.find('input[name=name]')
        form.on('submit', function (e) {
            e.preventDefault()
            if (!phoneNumber.val() || !name.val()) {
                notice(form, mwfc.messages.missing_field_value)
                return false;
            }
            btn.addClass('disabled');
            $.ajax({
                url: mwfc.au,
                type: 'post',
                dataType: 'json',
                data: {
                    action: 'mwfc_create_order_for_product',
                    nonce: form.attr('mwqp-nonce'),
                    qty: form.attr('mwqp-qty'),
                    pid: form.attr('pid'),
                    gateway: form.attr('gateway'),
                    phone: phoneNumber.val(),
                    name: name.val(),
                },
                success: response => {
                    let type = response.status === 'ok' ? 'success' : 'error'
                    if (response.msg) {
                        notice(form, response.msg, type)
                    }
                    if (response.status === 'ok') {
                        if (response.checkout_url) {
                            redirecting = true
                            notice(form, mwfc.messages.redirecting_to_payment_gateway, 'success')
                            window.location.href = response.checkout_url
                        }
                    }
                },
                error: err => {
                    notice(form, mwfc.messages.has_error_in_request)
                },
                complete: (xhr, status) => {
                    if(!redirecting)
                    {
                        btn.removeClass('disabled')
                    }
                }
            })
        })
    })
})